# -*- encoding: utf-8 -*-
#
#    This is pncconf2, a graphical configuration editor for LinuxCNC
#    Copyright 2013 Arvid Brodin
#
#    This is based on pncconf (Copyright 2009 Chris Morley),
#    in turn based on stepconf, a graphical configuration editor for
#    linuxcnc (Copyright 2007 Jeff Epler <jepler@unpythonic.net>).
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from halcomp.halcomp import HalComp

class HalCompPid(HalComp):

	def __init__(self, name, axisno):
		HalComp.__init__(self, name)
		self._params = []
		self._params.append(["Pgain", "[AXIS_%d]P" % axisno])
		self._params.append(["Igain", "[AXIS_%d]I" % axisno])
		self._params.append(["Dgain", "[AXIS_%d]D" % axisno])
		self._params.append(["bias", "[AXIS_%d]BIAS" % axisno])
		self._params.append(["FF0", "[AXIS_%d]FF0" % axisno])
		self._params.append(["FF1", "[AXIS_%d]FF1" % axisno])
		self._params.append(["FF2", "[AXIS_%d]FF2" % axisno])
		self._params.append(["deadband", "[AXIS_%d]DEADBAND" % axisno])
		self._params.append(["maxoutput", "[AXIS_%d]MAX_OUTPUT" % axisno])
		#self._params.append(["maxerror", "?"])
		#self._params.append(["maxerrorD", "?"])
		#self._params.append(["maxerrorI", "?"])
		#self._params.append(["maxcmdD", "?"])
		#self._params.append(["maxcmdDD", "?"])

	def generate_nets(self, nets):
		HalComp._net(self, nets, "pos-cmd", "=>", "command")
		HalComp._net(self, nets, "vel-fb", "=>", "command-deriv")
		HalComp._net(self, nets, "pos-fb", "=>", "feedback")
		#HalComp._net(self, nets, "?", "=>", "feedback-deriv")
		#HalComp._net(self, nets, "?", "=>", "error-previous-target")
		#HalComp._net(self, nets, "?", "<=", "error")
		HalComp._net(self, nets, "output", "<=", "output")
		HalComp._net(self, nets, "enable", "=>", "enable")
		HalComp._net(self, nets, "index-enable", "=>", "index-enable")
		#HalComp._net(self, nets, "?", "<=", "saturated")
		#HalComp._net(self, nets, "?", "<=", "saturated-s")
		#HalComp._net(self, nets, "?", "<=", "saturated-count")


class HalCompAxis(HalComp):

	def __init__(self, name):
		HalComp.__init__(self, name)
		self._params = []

	def generate_nets(self, nets):
		HalComp._net(self, nets, "enable", "<=", "amp-enable-out")
		#HalComp._net(self, nets, "", "=>", "amp-fault-in")
		HalComp._net(self, nets, "home", "=>", "home-sw-in")
		#HalComp._net(self, nets, "", "<=", "homing")
		HalComp._net(self, nets, "index-enable", "<=>", "index-enable")
		#HalComp._net(self, nets, "", "=>", "is-unlocked")
		#HalComp._net(self, nets, "", "=>", "jog-counts")
		#HalComp._net(self, nets, "", "=>", "jog-enable")
		#HalComp._net(self, nets, "", "=>", "jog-scale")
		#HalComp._net(self, nets, "", "=>", "jog-vel-mode")
		#HalComp._net(self, nets, "", "<=", "joint-pos-cmd")
		#HalComp._net(self, nets, "", "<=", "joint-pos-fb")
		HalComp._net(self, nets, "pos-cmd", "<=", "motor-pos-cmd")
		HalComp._net(self, nets, "pos-fb", "=>", "motor-pos-fb")
		HalComp._net(self, nets, "min", "=>", "neg-lim-sw-in")
		HalComp._net(self, nets, "max", "=>", "pos-lim-sw-in")
		#HalComp._net(self, nets, "", "<=", "unlock")
