# -*- encoding: utf-8 -*-
#
#    This is pncconf2, a graphical configuration editor for LinuxCNC
#    Copyright 2013 Arvid Brodin
#
#    This is based on pncconf (Copyright 2009 Chris Morley),
#    in turn based on stepconf, a graphical configuration editor for
#    linuxcnc (Copyright 2007 Jeff Epler <jepler@unpythonic.net>).
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from halcomp.mesa.hm2 import *

class Hardware(object):

	def __init__(self, halname, cardno):
		self.halname = halname + "." + str(cardno)

#		self.upconn = type(MesaP25)

		self.connectors = []
#		self.connectors.append(SSerial())

		self.mesacomp = []

	def display(self, parent):
		for mcomp in self.mesacomp:
			mcomp.display(parent + self.halname + ".")


class M7I76(Hardware):

	def __init__(self, cardno):
		Hardware.__init__(self, "7i76", cardno)
		for i in range(4):
			self.mesacomp.append(MesaStepDir(
				"TB2-STEPDIR" + str(i),
				"stepgen." + format(i, "02d")))
		self.mesacomp.append(MesaStepDir(
			"TB3-STEPDIR4",
			"stepgen.04"))
		self.mesacomp.append(MesaEncoder(
			"TB3-ENCODER",
			"encoder.00"))
		self.mesacomp.append(MesaPWM(
			"TB4-SPINDLE",
			"analogout0"))

		for i in range(16):
			self.mesacomp.append(MesaInput(
				"TB6-INPUT" + format(i, "01d"),
				"input-" + format(i, "02d")))
		for i in range(8):
			self.mesacomp.append(MesaOutput(
				"TB6-OUTPUT" + format(i, "01d"),
				"output-" + format(i, "02d")))
		for i in range(16, 32):
			self.mesacomp.append(MesaInput(
				"TB5-INPUT" + format(i, "01d"),
				"input-" + format(i, "02d")))
		for i in range(8, 16):
			self.mesacomp.append(MesaOutput(
				"TB5-OUTPUT" + format(i, "01d"),
				"output-" + format(i, "02d")))


class M7I77(Hardware):

	def __init__(self, cardno):
		Hardware.__init__(self, "7i77", cardno)
		for i in range(3):
			self.mesacomp.append(MesaEncoder(
				"TB3-ENC" + str(i),
				"encoder." + format(i, "02d")))
		for i in range(4, 6):
			self.mesacomp.append(MesaEncoder(
				"TB4-ENC" + str(i),
				"encoder." + format(i, "02d")))
		for i in range(6):
			self.mesacomp.append(MesaPWM(
				"TB5-AOUT" + str(i),
				"1.analogout" + str(i)))
		for i in range(16):
			self.mesacomp.append(MesaInput(
				"TB8-INPUT" + format(i, "01d"),
				"0.input-" + format(i, "02d")))
		for i in range(8):
			self.mesacomp.append(MesaOutput(
				"TB8-OUTPUT" + format(i, "01d"),
				"0.output-" + format(i, "02d")))
		for i in range(16, 32):
			self.mesacomp.append(MesaInput(
				"TB7-INPUT" + format(i, "01d"),
				"0.input-" + format(i, "02d")))
		for i in range(8, 16):
			self.mesacomp.append(MesaOutput(
				"TB7-OUTPUT" + format(i, "01d"),
				"0.output-" + format(i, "02d")))
