# -*- encoding: utf-8 -*-
#
#    This is pncconf2, a graphical configuration editor for LinuxCNC
#    Copyright 2013 Arvid Brodin
#
#    This is based on pncconf (Copyright 2009 Chris Morley),
#    in turn based on stepconf, a graphical configuration editor for
#    linuxcnc (Copyright 2007 Jeff Epler <jepler@unpythonic.net>).
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from halcomp.halcomp import HalComp

class HM2PWMGen(HalComp):

	def __init__(self, name, axisno):
		HalComp.__init__(self, name)
		self._params = []
		self._params.append(["scale", "[AXIS_%d]_SCALE" % axisno])
		self._params.append(["output-type", ""])
		self._params.append(["pwm_frequency", ""])
		self._params.append(["pdm_frequency", ""])

	def generate_nets(self, nets):
		HalComp._net(self, nets, "?", "=>", "enable")
		#HalComp._net(self, nets, "?", "=>", "value")


# This is not documented?
class HM2AnalogOut(HalComp):

	def __init__(self, name, axisno, nameidx):
		HalComp.__init__(self, name)
		self._axisno = axisno
		self._nameidx = nameidx
		self._params = []
		self._params.append(["analogout%d-scalemax" % nameidx,
				"[AXIS_%d]OUTPUT_SCALE" % axisno])
		self._params.append(["analogout%d-minlim" % nameidx,
				"[AXIS_%d]OUTPUT_MIN_LIMIT" % axisno])
		self._params.append(["analogout%d-maxlim" % nameidx,
				"[AXIS_%d]OUTPUT_MAX_LIMIT" % axisno])

	def generate_nets(self, nets):
		HalComp._net(self, nets, "output", "=>", "analogout%d" % self._nameidx)
		if self._axisno == 0:
			HalComp._net(self, nets, "enable", "=>", "analogena")


class HM2Encoder(HalComp):

	def __init__(self, name, axisno):
		HalComp.__init__(self, name)
		self._params = []
		self._params.append(["scale", "[AXIS_%d]ENCODER_SCALE" % axisno])
		self._params.append(["index-invert", "0"])
		self._params.append(["index-mask", "0"])
		self._params.append(["index-mask-invert", "0"])
		self._params.append(["counter-mode", "0"])
		self._params.append(["filter", "1"])
		#self._params.append(["vel-timeout", "?"])

	def generate_nets(self, nets):
		#HalComp._net(self, nets, "?", "<=", "count")
		HalComp._net(self, nets, "pos-fb", "<=", "position")
		HalComp._net(self, nets, "vel-fb", "<=", "velocity")
		#HalComp._net(self, nets, "?", "=>", "reset")
		HalComp._net(self, nets, "index-enable", "<=>", "index-enable")
		HalComp._net(self, nets, "pos-rawcount", "<=", "rawcount")



"""
### hm2 components

class HM2Comp(halcomp):
	def __init__(self, userdev, haldev):
		self.userdev = userdev
		self.haldev = haldev

	def display(self, parent):
		print self.userdev + ":"
		print "\t" + parent + self.haldev

	def generate_hal(self, file):






class HM2Resolver(HM2Comp):

	def __init__(self, userdev, haldev):
		MesaComp.__init__(self, userdev, haldev)

	def display(self, parent):
		print self.userdev + ":"
		for dev in ["angle", "position", "velocity", "count", "rawcounts", "reset", "index-enable", "error", "scale", "velocity-scale", "excitation-khz"]:
			print "\t" + parent + self.haldev + "." + dev

	# nets : dictionary of net
	def setup_net(self, file, nets):

		net["pos-fb"].add_out(axis.feedback.name + ".position")
		net["vel-fb"].add_out(axis.feedback.name + ".velocity")
		net["index-enable"].add_bidir(axis.feedback.name + ".index-enable")
		net["pos-rawcounts"].add_out(axis.feedback.name + ".rawcounts")


class HM2PWMGen(HM2Comp):

	def __init__(self, userdev, haldev):
		MesaComp.__init__(self, userdev, haldev)

	def display(self, parent):
		print self.userdev + ":"
		for dev in ["enable", "value", "scale", "output-type", "pwm_frequency", "pdm_frequency"]:
			print "\t" + parent + self.haldev + "." + dev

class HM2StepGen(HM2Comp):

	def __init__(self, userdev, haldev):
		MesaComp.__init__(self, userdev, haldev)

	def display(self, parent):
		print self.userdev + ":"
		for dev in ["position-cmd", "velocity-cmd", "counts", "position-fb", "velocity-fb", "enable", "control-type", "position-scale", "maxvel", "maxaccel", "steplen", "stepspace", "dirsetup", "dirhold", "step_type"]:
			print "\t" + parent + self.haldev + "." + dev


class HM2Input(HM2Comp):

	def __init__(self, userdev, haldev):
		MesaComp.__init__(self, userdev, haldev)

class HM2Output(HM2Comp):

	def __init__(self, userdev, haldev):
		MesaComp.__init__(self, userdev, haldev)
"""
