# -*- encoding: utf-8 -*-
#
#    This is pncconf2, a graphical configuration editor for LinuxCNC
#    Copyright 2013 Arvid Brodin
#
#    This is based on pncconf (Copyright 2009 Chris Morley),
#    in turn based on stepconf, a graphical configuration editor for
#    linuxcnc (Copyright 2007 Jeff Epler <jepler@unpythonic.net>).
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

class NetError(Exception):
    """Net errors"""


class Net(object):

	def __init__(self, name):
		self.name = name
		self.pin_out = None
		self.pins_bidir = []
		self.pins_in = []

	def set_pin_out(self, pin):
		# pin: string (name of pin)

		if (not self.pin_out is None) or (len(self.pins_bidir) > 0):
			raise NetError("Net \"%s\": only one out pin may be connected." % self.name)
		self.pin_out = pin

	def add_pin_bidir(self, pin):
		# pin: string (name of pin)

		if self.pin_out:
			raise NetError("Net \"%s\": cannot have both out and bidir pins in net." % self.name)
		self.pins_bidir.append(pin)

	def add_pin_in(self, pin):
		# pin: string (name of pin)

		self.pins_in.append(pin)

	def generate_hal(self, file, prefix):
#		if not self.pins_in:
#			return -1 # No listeners
#		if (not self.pin_out) and (not self.pins_bidir):
#			raise NetError("Net \"%s\": no source pin for net!" % self.name)
		if self.pin_out:
			print >>file, ("net    %s " % (prefix + self.name).ljust(25) +
				"<= %s" % self.pin_out)
		for pin in self.pins_bidir:
			print >>file, ("net    %s " % (prefix + self.name).ljust(24) +
				"<=> %s" % pin)
		for pin in self.pins_in:
			print >>file, ("net    %s " % (prefix + self.name).ljust(25) +
				"=> %s" % pin)

		return 0
